<template>
    <div class="app-container">
       <el-form :model="queryParams" ref="queryRef" :inline="true">
          <el-form-item prop="name">
             <el-input
                v-model="queryParams.name"
                placeholder="请输入内容"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          >
        </el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加或修改对话框 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
                    <el-form-item label="参数名称" prop="name">
                        <el-input v-model="form.name" placeholder="请输入参数名称" />
                    </el-form-item>
                    <el-form-item label="参数标识" prop="mark">
                        <el-input v-model="form.mark" placeholder="请输入参数标识" />
                    </el-form-item>
                    <el-form-item label="参数单位" prop="unit">
                        <el-input v-model="form.unit" placeholder="请输入参数单位" />
                    </el-form-item>
                    <el-form-item></el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <script setup name="Menu">
 import commonParameters from "@/api/configuration/commonParameters/index.js";
 import setPostParams from "../../../utils/searchParams.js";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:queryParams.value.name,page:1})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */

const pageParam = ref({
    total:0,
    limit:0,
    page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
    name: '参数名称',
    mark: '参数标识',
    unit: '单位',
    createTimeView: '创建日期',
   })
 /** 获取列表 */
 async function getList(val) {
      loading.value = true;

     let postParam = setPostParams(val)
      await commonParameters().search(postParam).then((res) =>{
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
     console.log('132',form.value)
   open.value = true;
   title.value = "新增设备参数";
 }
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   form.value = Object.assign({},row)
   open.value = true;
   title.value = "修改设备参数";
 }
/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.name + '"的数据项?').then(function() {
    return commonParameters().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
    name: undefined,
},
rules: {
    name: [{ required: true, message: "请输入参数名称", trigger: "blur" }],
    mark: [{ required: true, message: "请输入参数标识", trigger: "blur" }],
    unit: [{ required: true, message: "请输入参数单位", trigger: "blur" }],
},
});
const { queryParams, form, rules } = toRefs(data);

 /** 提交按钮 */
 async function submitForm() {
   proxy.$refs["formRef"].validate( async valid => {
     if (valid) {
       if (form.value.id != undefined) {
           await commonParameters().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
           await commonParameters().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 /** 表单重置 */
 function reset() {
   form.value = {
       mark:'',
       name:'',
       unit:'',
   };
   proxy.resetForm("formRef");
 }
 getList();
 </script>
 